package SDON;

import SDON.sdonbuilder.sdonserialize.SDONSerializable;

/**
 * Object for containing the properties of a column in a table.
 */
public class ColumnProperties implements LineInterface<ColumnProperties>{
    /**
     * The index of the column.
     */
    @SDONSerializable
    public int Index = -1;
    
    /**
     * The thickness of the column borders in 1/100". Otherwise the thickness
     * is the default for the template.
     */
    @SDONSerializable
    public double LineThick = -1.0;
    
    /**
     * The thickness of the column borders in 1/100". 
     * @param lineThick - Thickness of line
     * @return ColumnProperties
     */
    public ColumnProperties SetLineThickness(double lineThick) {
    	LineThick = lineThick;
   	
   	return this;
   }
    
    /**
     * The line color of the column borders as a hex RGB value or color alias.
     * If omitted, the color is the default for the template.
     */
    @SDONSerializable
    public String LineColor = null;
    
    /**
     * The line color of the column borders as a hex RGB value or color alias.
     * @param lineColor - Color of line
     * @return ColumnProperties
     */
    public ColumnProperties SetLineColor(String lineColor) {
    	LineColor = lineColor;
   	
   	return this;
   }
    
    /**
     * The pattern of the line for the column border. Must be a value from the
     * LinePatterns enum.
     */
    @SDONSerializable
    public String LinePattern = null;
    
    /**
     * The pattern of the line for the column border. Must be a value from the
     * LinePatterns enum.
     * @param linePattern - Line pattern
     * @return ColumnProperties
     */
    public ColumnProperties SetLinePattern(String linePattern) {
    	LinePattern = linePattern;
   	
   	return this;
   }
    
    /**
     * The desired width of the column in 1/100". Note any change n column N’s
     * width reduces the width of column N+1 by the same amount.
     */
    @SDONSerializable
    public double Width = -1.0;
    
    /**
     * The desired width of the column in 1/100". Note any change n column N’s
     * width reduces the width of column N+1 by the same amount.
     * @param width - Width of column
     * @return ColumnProperties
     */
    public ColumnProperties SetWidth(double width) {
    	Width = width;
   	
   	return this;
   }
    
    /**
     * Makes the column not scale as the shape that contains the table grows.
     */
    @SDONSerializable
    public Boolean FixedWidth = null;
    
    /**
     * Makes the column not scale as the shape that contains the table grows.
     * @param fixedWidth - Make cell a fixed width
     * @return ColumnProperties
     */
    public ColumnProperties FixedWidth(Boolean fixedWidth) {
    	FixedWidth = fixedWidth;
   	
   	return this;
   }
}