package SDON;
import java.util.ArrayList;

import SDON.sdonbuilder.SDONBuilder;
import SDON.sdonbuilder.sdonserialize.SDONSerializable;


/**
 * Gantt document
 */
public class GanttDocument extends Document {
	
	
    /**
     * A special data table used when making Gantt charts, defines the row
     * values and relationships that are inserted into a Gantt chart. The field
     * names for the rows in this data table must be from the
     * {@link GanttChartColumnNames} enum.
     */
    @SDONSerializable
    public DataTableInstance UseDataTable = null;
    
	/**
	 * Add a Gantt Task
	 * @param fields - List of DataField name/value pairs for the Gantt task
	 * @return DataRow
	 */
    public DataRow AddTask(ArrayList<DataField> fields) {
		
		if (UseDataTable.Rows == null)
			UseDataTable.Rows = new ArrayList<DataRow>();
		
		DataRow dataRow = UseDataTable.AddDataRow();
		
		dataRow.SetValues(fields);
		
		return dataRow;
	}
	
    /**
     * Gantt Column settings. Override the name and default width of specifically-named columns
     */
    @SDONSerializable
    public ArrayList<GanttColumnSettings> GanttColumns = null;
    
    /**
     * Gantt Column settings. Override the name and default width of specifically-named columns
     * @param name - Defined name of column ("Task", "Start", "PercentComplete", etc).  From GanttChartColumnNames enum
     * @param title - Title to display for column instead of the name
     * @param width - Width of column
     * @return GanttDocument
     */
    public GanttDocument SetColumnSettings(String name, String title, int width) {
    	
    	if (GanttColumns == null)
    		GanttColumns = new ArrayList<GanttColumnSettings>();
    	
    	GanttColumnSettings ganttColumnSettings = null;
    	
    	for (GanttColumnSettings s:  GanttColumns ) {
    		if (s.Name == name) {
    			ganttColumnSettings = s;
    			break;
    		}    		
    	}
    	
    	if (ganttColumnSettings == null) {    	
    		ganttColumnSettings = new GanttColumnSettings();
    		ganttColumnSettings.Name = name;
    	}
    	
    	ganttColumnSettings.Title = title;
    	
    	ganttColumnSettings.Width = width;
    	
    	return this;
    }
    
    /**
     * Set Gantt options for country to use for holiday dates and whether all days should be considered working days
     */
    @SDONSerializable
    public GanttOptions GanttOptions  = null;   
    
    /**
     * et Gantt options for country to use for holiday dates and whether all days should be considered working days
     * @param allWorkingDays - Make all days working days (weekends, holidays)
     * @param holidayCountry - Country  to use for holidays.  From GanttChartHolidays enum.
     * @return GanttDocument
     */
    public GanttDocument SetGanttOptions(Boolean allWorkingDays, String holidayCountry) {
    	
    	if (GanttOptions == null) 
    		GanttOptions = new GanttOptions();
    	
    	GanttOptions.AllWorkingDays = allWorkingDays;
    	
    	GanttOptions.Holidays = holidayCountry;
    	
    	return this;
    }
    
 
    /**
     * Return the JSON representation of this document
     * @return JSON representation of document
     */
    public String toJSON() {
    	return SDONBuilder.<GanttDocument>ToJSON(this);
    }
    
    /**
     * Return a GanttDocument from an sdonstr (JSON)
     * @param sdonStr - String of SDON
     * @return Document
     */
    public static GanttDocument fromJSON(String sdonStr) {
    	return SDONBuilder.GanttDocumentFromJSON(sdonStr);
    }
    
    /**
     * Construct a new Gantt Document
     */
    public GanttDocument() {
    	
    	Template = SDONTemplates.Gantt;
    	
    	UseDataTable = new DataTableInstance();    	
    }
}