package SDON;

import SDON.sdonbuilder.sdonserialize.SDONSerializable;

/**
 * Object that represents the title of a diagram.
 */
public class Title implements TextInterfaceCore<Title>, TextInterfaceExtended<Title>{
    /**
     * The text to put as a title for the diagram.
     */
    @SDONSerializable
    public String Label = null;
    
    /**
     * Set text to for title for the document.
     * @param label - title text
     * @return Title
     */
    public Title SetLabel(String label) {
    	Label = label;
   	
   	return this;
   }
    
    /**
     * Makes the text label be bold with a value of true, not bold with false,
     * otherwise, if omitted, boldness follows the template default.
     */
    @SDONSerializable
    public Boolean TextBold = null;
    
    /**
     * Makes the text label be bold with a value of true, not bold with false,
     * otherwise, if omitted, boldness follows the template default.
     * @param textBold - Bold text
     * @return Title
     */
    public Title SetTextBold(Boolean textBold) {
    	TextBold= textBold;
   	
   	return this;
   }
    
    /**
     * Makes the text label be italic with a value of true, not italic with
     * false, otherwise, if omitted, italic follows the template default.
     */
    @SDONSerializable
    public Boolean TextItalic = null;
    
    /**
     * Makes the text label be italic with a value of true, not italic with
     * false, otherwise, if omitted, italic follows the template default.
     * @param textItalic - Italic text
     * @return Title
     */
    public Title SetTextItalic(Boolean textItalic) {
    	TextItalic = textItalic;
   	
   	return this;
   }
    
    /**
     * Makes the text label be underlined with a value of true, not underlined
     * with false, otherwise, if omitted, underlined follows the template
     * default.
     */
    @SDONSerializable
    public Boolean TextUnderline = null;
    
    /**
     * Makes the text label be underlined with a value of true, not underlined
     * with false, otherwise, if omitted, underlined follows the template
     * default.
     * @param textUnderline - Underlined text
     * @return Title
     */
    public Title SetTextUnderline(Boolean textUnderline) {
    	TextUnderline = textUnderline;
   	
   	return this;
   }
    
    /**
     * The point size of the text label the specified value. If omitted, the
     * text size is the default for the template.
     */
    @SDONSerializable
    public double TextSize = -1;
    
    /**
     * The point size of the text label the specified value. If omitted, the
     * text size is the default for the template.
     * @param textSize - Text size
     * @return Title
     */
    public Title SetTextSize(double textSize) {
    	TextSize = textSize;
   	
   	return this;
   }
    
    /**
     * The font of the text label the specified value. If omitted, the font is
     * the default for the template. Any font can be defined, but will fall
     * back to system default if font is unavailable.
     */
    @SDONSerializable
    public String TextFont = null;
    
    /**
     * The font of the text label the specified value. If omitted, the font is
     * the default for the template. Any font can be defined, but will fall
     * back to system default if font is unavailable.
     * @param textFont - Font string
     * @return Title
     */
    public Title SetTextFont(String textFont) {
    	TextFont = textFont;
   	
   	return this;
   }
    
    /**
     * The color of the text label of the shape (hex RGB value). If omitted,
     * the color is the default for the template.
     */
    @SDONSerializable
    public String TextColor = null;
    
    /**
     * The color of the text label of the shape (hex RGB value). If omitted,
     * the color is the default for the template.
     * @param textColor - Text color
     * @return Title 
     */
    public Title SetTextColor(String textColor) {
    	TextColor = textColor;
   	
   	return this;
   }
    
    /**
     * Hyperlink set on text label
     */
    @SDONSerializable
    public String TextHyperlink = null;
    
    /**
     * Hyperlink set on text label
     * @param textHyperlink - Hyperlink URL
     * @return Title
     */
    public Title SetTextHyperlink(String textHyperlink) {
    	TextHyperlink = textHyperlink;
   	
   	return this;
   }   
    
    /**
     * Truncate text after specific number of characters
     */
    @SDONSerializable
    public int Truncate = -2;
    
    /**
     * Truncate text after specific number of characters
     * @param truncate - Maximum number of characters to display before truncation
     * @return Title
     */
    public Title SetTextTruncate(int truncate) {
    	Truncate = truncate;
   	
   	return this;
   } 
}